@@ -3,5 +3,8 @@ from actionpack import Action
 
 class ReadInput(Action):
     def __init__(self, prompt: str):
-        self.instruction = lambda: input(prompt)
+        self.prompt = prompt
+
+    def instruction(self) -> str:
+        return input(self.prompt)
 
